'''
Utilities for processing WAD files
'''

from enum import Enum
import os
import sys

class WADType(Enum):
	IWAD = 'IWAD'
	PWAD = 'PWAD'

class WADFile(object):
	__fo = None
	wadType = None

	def __init__(self, filename):
		self.filename = filename

	def __enter__(self):
		self.open()
		return self

	def __exit__(self, exception_type, exception_value, exception_traceback):
		self.close()

	def open(self):
		'''Opens a WAD file in binary mode for reading'''

		# Return early if the WAD file is already opon
		if(self.__fo != None):
			return True

		# Attempt to open file
		try:
			self.__fo = open(self.filename, 'rb')
		except Exception:
			print('Could not open WAD file {0}'.format(self.filename), file=sys.stderr)
			return None

		# Read first 4 bytes to check WAD type
		magic = self.__fo.read(4).decode('ascii')
		if(magic == 'IWAD'):
			self.wadType = WADType.IWAD
		elif(magic == 'PWAD'):
			self.wadType = WADType.PWAD
		else:
			print('File {0} is not in a WAD format'.format(self.filename))
			self.close()

		# Return WADFile
		return self

	def close(self):
		'''Close internal file object'''

		if(self.__fo != None):
			self.__fo.close()

		self.__fo = None
		self.wadType = None